@@ -2,6 +2,7 @@ package listen
 
 import (
 	"bytes"
+	"context"
 	"encoding/json"
 	"fmt"
 	"io"
@@ -20,13 +21,23 @@ var (
 	upgrader = websocket.Upgrader{}
 )
 
-func wsHandler(t *testing.T) http.HandlerFunc {
+func wsHandler(t *testing.T, recvBuffer *bytes.Buffer) http.HandlerFunc {
 	return func(w http.ResponseWriter, r *http.Request) {
 		c, err := upgrader.Upgrade(w, r, nil)
 		require.NoError(t, err)
 		defer c.Close()
 		i := 0
 		finish := 5
+		go func() {
+			// Read messages from websocket and write to buffer
+			for {
+				_, message, err := c.ReadMessage()
+				if err != nil {
+					return
+				}
+				recvBuffer.Write(message)
+			}
+		}()
 		for {
 			// Give the Close test a chance to close before any sent
 			time.Sleep(time.Millisecond * 10)
@@ -38,7 +49,8 @@ func wsHandler(t *testing.T) http.HandlerFunc {
 				Message: fmt.Sprintf("%d\n", i),
 			}
 			buf := new(bytes.Buffer)
-			json.NewEncoder(buf).Encode(data)
+			err := json.NewEncoder(buf).Encode(data)
+			require.NoError(t, err)
 
 			err = c.WriteMessage(websocket.TextMessage, buf.Bytes())
 			require.NoError(t, err)
@@ -47,11 +59,13 @@ func wsHandler(t *testing.T) http.HandlerFunc {
 				break
 			}
 		}
+		err = c.WriteMessage(websocket.CloseMessage, websocket.FormatCloseMessage(websocket.CloseNormalClosure, ""))
+		require.NoError(t, err)
 	}
 }
 
 func TestListener(t *testing.T) {
-	server := httptest.NewServer(wsHandler(t))
+	server := httptest.NewServer(wsHandler(t, nil))
 	defer server.Close()
 
 	u := "ws" + strings.TrimPrefix(server.URL, "http")
@@ -60,8 +74,8 @@ func TestListener(t *testing.T) {
 
 	buffer := &bytes.Buffer{}
 
-	listener := NewListener(url, "", nil, buffer)
-	err = listener.Start()
+	listener := NewListener(url, "", nil, buffer, nil)
+	err = listener.Listen(context.Background())
 	require.NoError(t, err)
 
 	want := `{"message":"1\n"}
@@ -74,7 +88,7 @@ func TestListener(t *testing.T) {
 }
 
 func TestListenerWithSchemaFunc(t *testing.T) {
-	server := httptest.NewServer(wsHandler(t))
+	server := httptest.NewServer(wsHandler(t, nil))
 	defer server.Close()
 
 	u := "ws" + strings.TrimPrefix(server.URL, "http")
@@ -96,8 +110,8 @@ func TestListenerWithSchemaFunc(t *testing.T) {
 		return r, nil
 	}
 
-	listener := NewListener(url, "", schemaFunc, buffer)
-	err = listener.Start()
+	listener := NewListener(url, "", schemaFunc, buffer, nil)
+	err = listener.Listen(context.Background())
 	require.NoError(t, err)
 
 	want := `1
@@ -109,20 +123,30 @@ func TestListenerWithSchemaFunc(t *testing.T) {
 	require.Equal(t, want, buffer.String())
 }
 
-func TestListenerStop(t *testing.T) {
-	server := httptest.NewServer(wsHandler(t))
+func TestListenerWithInput(t *testing.T) {
+	wsInBuf := &bytes.Buffer{}
+	server := httptest.NewServer(wsHandler(t, wsInBuf))
 	defer server.Close()
 
 	u := "ws" + strings.TrimPrefix(server.URL, "http")
 	url, err := url.Parse(u)
 	require.NoError(t, err)
 
-	buffer := &bytes.Buffer{}
+	inputCh := make(chan []byte, 5)
+	for i := 0; i < 5; i++ {
+		inputCh <- []byte{byte('a' + i)}
+	}
+	wsOutBuf := &bytes.Buffer{}
+	listener := NewListener(url, "", nil, wsOutBuf, inputCh)
+	err = listener.Listen(context.Background())
+	require.NoError(t, err)
 
-	listener := NewListener(url, "", nil, buffer)
-	go listener.Start()
-	// Stop before any messages have been sent
-	listener.Stop()
-
-	require.Equal(t, "", buffer.String())
+	want := `{"message":"1\n"}
+{"message":"2\n"}
+{"message":"3\n"}
+{"message":"4\n"}
+{"message":"5\n"}
+`
+	require.Equal(t, want, wsOutBuf.String())
+	require.Equal(t, "abcde", wsInBuf.String())
 }
